--[[
	No Day / Night Addon for World of Warcraft(tm).
	Version: 1.0

	License:
		This program is free software; you can redistribute it and/or
		modify it under the terms of the GNU General Public License
		as published by the Free Software Foundation; either version 2
		of the License, or (at your option) any later version.

		This program is distributed in the hope that it will be useful,
		but WITHOUT ANY WARRANTY; without even the implied warranty of
		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
		GNU General Public License for more details.

		You should have received a copy of the GNU General Public License
		along with this program(see GPL.txt); if not, write to the Free Software
		Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

	Note:
		This AddOn's source code is specifically designed to work with
		World of Warcraft's interpreted AddOn system.
		You have an implicit licence to use this AddOn with these facilities
		since that is it's designated purpose as per:
		http://www.fsf.org/licensing/licenses/gpl-faq.html#InterpreterIncompat
]]

--------------------------------------------------------------------------------
-- Function definations                                                       --
--------------------------------------------------------------------------------
local getLocalizedString
local initialize
local onEvent
local toggleDNIRemover

--------------------------------------------------------------------------------
-- Table definitions                                                          --
--------------------------------------------------------------------------------
-- NODYNIGHT {         -- global access table
--   OnLoad,           -- function onLoad()
--   ToggleDNIRemover, -- function toggleDNIRemover()
--   Locale            -- localisation table
-- }
--
-- Locale { -- localisation table
--    deDE, -- contains localised strings for German clients
--    enEN  -- contains localised strings for English clients
-- }
--
-- Localised strings:
-- BINDING_HEADER = Header for the key binding entry in WoW's key binding menu
-- BINDING_NAME   = Name of the key binding entry

--------------------------------------------------------------------------------
-- Captured events                                                            --
--------------------------------------------------------------------------------
-- ADDON_LOADED - processed in onEvent function

--------------------------------------------------------------------------------
-- Called, when the an event is triggered for the addon.
-- Handles the ADDON_LOADED event, to perform final initialisation steps after
-- all files are loaded.
-- 
-- Note:
--    event is set by WoW to the event, which triggered the function call.
--------------------------------------------------------------------------------
function onEvent()
	if event == "ADDON_LOADED" then
		initialize()
	end
end

--------------------------------------------------------------------------------
-- Called, when the addon is loaded to initialially hide the GameTimeFrame and
-- set the localized strings for the key binding menu
--------------------------------------------------------------------------------
function initialize()
	HideUIPanel(GameTimeFrame)
	BINDING_HEADER_DNIREMOVER = getLocalizedString("BINDING_HEADER")
	BINDING_NAME_DNIREMOVER   = getLocalizedString("BINDING_NAME")
end

--------------------------------------------------------------------------------
-- Called, when the user pressed the "toggle DN button". Can also be called by
-- macros or other addons.
-- If the GameTimeFrame is currently shown, it hides it, otherwise the frame
-- will be displayed.
--------------------------------------------------------------------------------
function toggleDNIRemover()
	if (GameTimeFrame:IsVisible()) then
		HideUIPanel(GameTimeFrame)
	else
		ShowUIPanel(GameTimeFrame)
	end
end

--------------------------------------------------------------------------------
-- The function returns the localised string for the given identifier.
-- If there is no localisation for the current language, the default (enUS) will
-- be used instead.
--
-- param:
--    strID (string) = the identifier of the requested string
-- return
--    (string) the requested string
--    nil, if the string does not exist
--------------------------------------------------------------------------------
function getLocalizedString(strID)
	local lang = GetLocale()

	if not NODAYNIGHT.Locale[lang] then
		lang = "enUS"
	end
	
	return NODAYNIGHT.Locale[lang][strID]
end

--------------------------------------------------------------------------------
-- Public access table                                                        --
--------------------------------------------------------------------------------
NODAYNIGHT = {
   OnEvent          = onEvent,
   ToggleDNIRemover = toggleDNIRemover,
   Locale           = {}
}

--------------------------------------------------------------------------------
-- Initialization code
--
-- Creates an invisible frame, only used to initialize the addon
--------------------------------------------------------------------------------
local frame = CreateFrame("Frame", "NoDayNight")
-- Note: OnLoad can not be used, since OnLoad would be called BEFORE the
--       localisation files have been processed. Therefore the ADDON_LOADED
--       event is used to finish the initialisation
frame:RegisterEvent("ADDON_LOADED")
frame:SetScript("OnEvent", NODAYNIGHT.OnEvent)